@@ -7,7 +7,9 @@ from .errors import ValidationFailure
 class ValidationReport:
     """Class for reporting the results of validation."""
 
-    def __init__(self, errors_to_suppress: List[ValidationFailure], data_source: str = ""):
+    # pylint: disable=R0902
+    def __init__(self, errors_to_suppress: List[ValidationFailure],
+                 data_source: str = "", dry_run: bool = False):
         """Initialize a ValidationReport.
 
         Parameters
@@ -41,6 +43,8 @@ class ValidationReport:
         self.raised_errors = []
         self.raised_warnings = []
         self.unsuppressed_errors = []
+        self.dry_run = dry_run
+    # pylint: enable=R0902
 
     def add_raised_error(self, error):
         """Add an error to the report.
@@ -120,4 +124,4 @@ class ValidationReport:
 
     def success(self):
         """Determine if the report corresponds to a successful validation run."""
-        return len(self.unsuppressed_errors) == 0
+        return len(self.unsuppressed_errors) == 0 or self.dry_run
